<?php
session_start(); // Initialize session data
ob_start(); // Turn on output buffering
?>
<?php include "ewcfg6.php" ?>
<?php include "ewmysql6.php" ?>
<?php include "phpfn6.php" ?>
<?php include "pv_deltron_catinfo.php" ?>
<?php include "usuarioinfo.php" ?>
<?php include "userfn6.php" ?>
<?php
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); // Always modified
header("Cache-Control: private, no-store, no-cache, must-revalidate"); // HTTP/1.1 
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache"); // HTTP/1.0
?>
<?php

// Define page object
$pv_deltron_cat_delete = new cpv_deltron_cat_delete();
$Page =& $pv_deltron_cat_delete;

// Page init processing
$pv_deltron_cat_delete->Page_Init();

// Page main processing
$pv_deltron_cat_delete->Page_Main();
?>
<?php include "header.php" ?>
<script type="text/javascript">
<!--

// Create page object
var pv_deltron_cat_delete = new ew_Page("pv_deltron_cat_delete");

// page properties
pv_deltron_cat_delete.PageID = "delete"; // page ID
var EW_PAGE_ID = pv_deltron_cat_delete.PageID; // for backward compatibility

// extend page with Form_CustomValidate function
pv_deltron_cat_delete.Form_CustomValidate = 
 function(fobj) { // DO NOT CHANGE THIS LINE!

 	// Your custom validation code here, return false if invalid. 
 	return true;
 }
<?php if (EW_CLIENT_VALIDATE) { ?>
pv_deltron_cat_delete.ValidateRequired = true; // uses JavaScript validation
<?php } else { ?>
pv_deltron_cat_delete.ValidateRequired = false; // no JavaScript validation
<?php } ?>

//-->
</script>
<script language="JavaScript" type="text/javascript">
<!--

// Write your client script here, no need to add script tags.
// To include another .js script, use:
// ew_ClientScriptInclude("my_javascript.js"); 
//-->

</script>
<?php

// Load records for display
$rs = $pv_deltron_cat_delete->LoadRecordset();
$pv_deltron_cat_deletelTotalRecs = $rs->RecordCount(); // Get record count
if ($pv_deltron_cat_deletelTotalRecs <= 0) { // No record found, exit
	$rs->Close();
	$pv_deltron_cat_delete->Page_Terminate("pv_deltron_catlist.php"); // Return to list
}
?>
<p><span class="phpmaker">Borrar de TABLA: DTcat<br><br>
<a href="<?php echo $pv_deltron_cat->getReturnUrl() ?>">Regresar</a></span></p>
<?php $pv_deltron_cat_delete->ShowMessage() ?>
<form action="<?php echo ew_CurrentPage() ?>" method="post">
<p>
<input type="hidden" name="t" id="t" value="pv_deltron_cat">
<input type="hidden" name="a_delete" id="a_delete" value="D">
<?php foreach ($pv_deltron_cat_delete->arRecKeys as $key) { ?>
<input type="hidden" name="key_m[]" id="key_m[]" value="<?php echo ew_HtmlEncode($key) ?>">
<?php } ?>
<table class="ewGrid"><tr><td class="ewGridContent">
<div class="ewGridMiddlePanel">
<table cellspacing="0" class="ewTable ewTableSeparate">
<?php echo $pv_deltron_cat->TableCustomInnerHtml ?>
	<thead>
	<tr class="ewTableHeader">
		<td valign="top">Id</td>
		<td valign="top">Categoria</td>
		<td valign="top">Margen</td>
	</tr>
	</thead>
	<tbody>
<?php
$pv_deltron_cat_delete->lRecCnt = 0;
$i = 0;
while (!$rs->EOF) {
	$pv_deltron_cat_delete->lRecCnt++;

	// Set row properties
	$pv_deltron_cat->CssClass = "";
	$pv_deltron_cat->CssStyle = "";
	$pv_deltron_cat->RowType = EW_ROWTYPE_VIEW; // View

	// Get the field contents
	$pv_deltron_cat_delete->LoadRowValues($rs);

	// Render row
	$pv_deltron_cat_delete->RenderRow();
?>
	<tr<?php echo $pv_deltron_cat->RowAttributes() ?>>
		<td<?php echo $pv_deltron_cat->id->CellAttributes() ?>>
<div<?php echo $pv_deltron_cat->id->ViewAttributes() ?>><?php echo $pv_deltron_cat->id->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron_cat->categoria->CellAttributes() ?>>
<div<?php echo $pv_deltron_cat->categoria->ViewAttributes() ?>><?php echo $pv_deltron_cat->categoria->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron_cat->margen->CellAttributes() ?>>
<div<?php echo $pv_deltron_cat->margen->ViewAttributes() ?>><?php echo $pv_deltron_cat->margen->ListViewValue() ?></div></td>
	</tr>
<?php
	$rs->MoveNext();
}
$rs->Close();
?>
</tbody>
</table>
</div>
</td></tr></table>
<p>
<input type="submit" name="Action" id="Action" value="Confirmar Borrado">
</form>
<script language="JavaScript" type="text/javascript">
<!--

// Write your table-specific startup script here
// document.write("page loaded");
//-->

</script>
<?php include "footer.php" ?>
<?php

//
// Page Class
//
class cpv_deltron_cat_delete {

	// Page ID
	var $PageID = 'delete';

	// Table Name
	var $TableName = 'pv_deltron_cat';

	// Page Object Name
	var $PageObjName = 'pv_deltron_cat_delete';

	// Page Name
	function PageName() {
		return ew_CurrentPage();
	}

	// Page Url
	function PageUrl() {
		$PageUrl = ew_CurrentPage() . "?";
		global $pv_deltron_cat;
		if ($pv_deltron_cat->UseTokenInUrl) $PageUrl .= "t=" . $pv_deltron_cat->TableVar . "&"; // add page token
		return $PageUrl;
	}

	// Message
	function getMessage() {
		return @$_SESSION[EW_SESSION_MESSAGE];
	}

	function setMessage($v) {
		if (@$_SESSION[EW_SESSION_MESSAGE] <> "") { // Append
			$_SESSION[EW_SESSION_MESSAGE] .= "<br>" . $v;
		} else {
			$_SESSION[EW_SESSION_MESSAGE] = $v;
		}
	}

	// Show Message
	function ShowMessage() {
		if ($this->getMessage() <> "") { // Message in Session, display
			echo "<p><span class=\"ewMessage\">" . $this->getMessage() . "</span></p>";
			$_SESSION[EW_SESSION_MESSAGE] = ""; // Clear message in Session
		}
	}

	// Validate Page request
	function IsPageRequest() {
		global $objForm, $pv_deltron_cat;
		if ($pv_deltron_cat->UseTokenInUrl) {

			//IsPageRequest = False
			if ($objForm)
				return ($pv_deltron_cat->TableVar == $objForm->GetValue("t"));
			if (@$_GET["t"] <> "")
				return ($pv_deltron_cat->TableVar == $_GET["t"]);
		} else {
			return TRUE;
		}
	}

	//
	//  Class initialize
	//  - init objects
	//  - open connection
	//
	function cpv_deltron_cat_delete() {
		global $conn;

		// Initialize table object
		$GLOBALS["pv_deltron_cat"] = new cpv_deltron_cat();

		// Initialize other table object
		$GLOBALS['usuario'] = new cusuario();

		// Intialize page id (for backward compatibility)
		if (!defined("EW_PAGE_ID"))
			define("EW_PAGE_ID", 'delete', TRUE);

		// Initialize table name (for backward compatibility)
		if (!defined("EW_TABLE_NAME"))
			define("EW_TABLE_NAME", 'pv_deltron_cat', TRUE);

		// Open connection to the database
		$conn = ew_Connect();
	}

	// 
	//  Page_Init
	//
	function Page_Init() {
		global $gsExport, $gsExportFile, $pv_deltron_cat;
		global $Security;
		$Security = new cAdvancedSecurity();
		if (!$Security->IsLoggedIn()) $Security->AutoLogin();
		if (!$Security->IsLoggedIn()) {
			$Security->SaveLastUrl();
			$this->Page_Terminate("login.php");
		}

		// Global page loading event (in userfn6.php)
		Page_Loading();

		// Page load event, used in current page
		$this->Page_Load();
	}

	//
	//  Page_Terminate
	//  - called when exit page
	//  - if URL specified, redirect to the URL
	//
	function Page_Terminate($url = "") {
		global $conn;

		// Page unload event, used in current page
		$this->Page_Unload();

		// Global page unloaded event (in userfn*.php)
		Page_Unloaded();

		 // Close Connection
		$conn->Close();

		// Go to URL if specified
		if ($url <> "") {
			ob_end_clean();
			header("Location: $url");
		}
		exit();
	}
	var $lTotalRecs;
	var $lRecCnt;
	var $arRecKeys = array();

	// Page main processing
	function Page_Main() {
		global $pv_deltron_cat;

		// Load Key Parameters
		$sKey = "";
		$bSingleDelete = TRUE; // Initialize as single delete
		$nKeySelected = 0; // Initialize selected key count
		$sFilter = "";
		if (@$_GET["id"] <> "") {
			$pv_deltron_cat->id->setQueryStringValue($_GET["id"]);
			if (!is_numeric($pv_deltron_cat->id->QueryStringValue))
				$this->Page_Terminate("pv_deltron_catlist.php"); // Prevent SQL injection, exit
			$sKey .= $pv_deltron_cat->id->QueryStringValue;
		} else {
			$bSingleDelete = FALSE;
		}
		if ($bSingleDelete) {
			$nKeySelected = 1; // Set up key selected count
			$this->arRecKeys[0] = $sKey;
		} else {
			if (isset($_POST["key_m"])) { // Key in form
				$nKeySelected = count($_POST["key_m"]); // Set up key selected count
				$this->arRecKeys = ew_StripSlashes($_POST["key_m"]);
			}
		}
		if ($nKeySelected <= 0)
			$this->Page_Terminate("pv_deltron_catlist.php"); // No key specified, return to list

		// Build filter
		foreach ($this->arRecKeys as $sKey) {
			$sFilter .= "(";

			// Set up key field
			$sKeyFld = $sKey;
			if (!is_numeric($sKeyFld))
				$this->Page_Terminate("pv_deltron_catlist.php"); // Prevent SQL injection, return to list
			$sFilter .= "`id`=" . ew_AdjustSql($sKeyFld) . " AND ";
			if (substr($sFilter, -5) == " AND ") $sFilter = substr($sFilter, 0, strlen($sFilter)-5) . ") OR ";
		}
		if (substr($sFilter, -4) == " OR ") $sFilter = substr($sFilter, 0, strlen($sFilter)-4);

		// Set up filter (SQL WhHERE clause) and get return SQL
		// SQL constructor in SQL constructor in pv_deltron_cat class, pv_deltron_catinfo.php

		$pv_deltron_cat->CurrentFilter = $sFilter;

		// Get action
		if (@$_POST["a_delete"] <> "") {
			$pv_deltron_cat->CurrentAction = $_POST["a_delete"];
		} else {
			$pv_deltron_cat->CurrentAction = "I"; // Display record
		}
		switch ($pv_deltron_cat->CurrentAction) {
			case "D": // Delete
				$pv_deltron_cat->SendEmail = TRUE; // Send email on delete success
				if ($this->DeleteRows()) { // delete rows
					$this->setMessage("Borrado con exito"); // Set up success message
					$this->Page_Terminate($pv_deltron_cat->getReturnUrl()); // Return to caller
				}
		}
	}

	//
	//  Function DeleteRows
	//  - Delete Records based on current filter
	//
	function DeleteRows() {
		global $conn, $Security, $pv_deltron_cat;
		$DeleteRows = TRUE;
		$sWrkFilter = $pv_deltron_cat->CurrentFilter;

		// Set up filter (Sql Where Clause) and get Return SQL
		// SQL constructor in pv_deltron_cat class, pv_deltron_catinfo.php

		$pv_deltron_cat->CurrentFilter = $sWrkFilter;
		$sSql = $pv_deltron_cat->SQL();
		$conn->raiseErrorFn = 'ew_ErrorFn';
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';
		if ($rs === FALSE) {
			return FALSE;
		} elseif ($rs->EOF) {
			$this->setMessage("No se encontraron registros"); // No record found
			$rs->Close();
			return FALSE;
		}
		$conn->BeginTrans();

		// Clone old rows
		$rsold = ($rs) ? $rs->GetRows() : array();
		if ($rs) $rs->Close();

		// Call row deleting event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$DeleteRows = $pv_deltron_cat->Row_Deleting($row);
				if (!$DeleteRows) break;
			}
		}
		if ($DeleteRows) {
			$sKey = "";
			foreach ($rsold as $row) {
				$sThisKey = "";
				if ($sThisKey <> "") $sThisKey .= EW_COMPOSITE_KEY_SEPARATOR;
				$sThisKey .= $row['id'];
				$conn->raiseErrorFn = 'ew_ErrorFn';
				$DeleteRows = $conn->Execute($pv_deltron_cat->DeleteSQL($row)); // Delete
				$conn->raiseErrorFn = '';
				if ($DeleteRows === FALSE)
					break;
				if ($sKey <> "") $sKey .= ", ";
				$sKey .= $sThisKey;
			}
		} else {

			// Set up error message
			if ($pv_deltron_cat->CancelMessage <> "") {
				$this->setMessage($pv_deltron_cat->CancelMessage);
				$pv_deltron_cat->CancelMessage = "";
			} else {
				$this->setMessage("Borrar cancelado");
			}
		}
		if ($DeleteRows) {
			$conn->CommitTrans(); // Commit the changes
		} else {
			$conn->RollbackTrans(); // Rollback changes
		}

		// Call recordset deleted event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$pv_deltron_cat->Row_Deleted($row);
			}	
		}
		return $DeleteRows;
	}

	// Load recordset
	function LoadRecordset($offset = -1, $rowcnt = -1) {
		global $conn, $pv_deltron_cat;

		// Call Recordset Selecting event
		$pv_deltron_cat->Recordset_Selecting($pv_deltron_cat->CurrentFilter);

		// Load list page SQL
		$sSql = $pv_deltron_cat->SelectSQL();
		if ($offset > -1 && $rowcnt > -1) $sSql .= " LIMIT $offset, $rowcnt";

		// Load recordset
		$conn->raiseErrorFn = 'ew_ErrorFn';	
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';

		// Call Recordset Selected event
		$pv_deltron_cat->Recordset_Selected($rs);
		return $rs;
	}

	// Load row based on key values
	function LoadRow() {
		global $conn, $Security, $pv_deltron_cat;
		$sFilter = $pv_deltron_cat->KeyFilter();

		// Call Row Selecting event
		$pv_deltron_cat->Row_Selecting($sFilter);

		// Load sql based on filter
		$pv_deltron_cat->CurrentFilter = $sFilter;
		$sSql = $pv_deltron_cat->SQL();
		if ($rs = $conn->Execute($sSql)) {
			if ($rs->EOF) {
				$LoadRow = FALSE;
			} else {
				$LoadRow = TRUE;
				$rs->MoveFirst();
				$this->LoadRowValues($rs); // Load row values

				// Call Row Selected event
				$pv_deltron_cat->Row_Selected($rs);
			}
			$rs->Close();
		} else {
			$LoadRow = FALSE;
		}
		return $LoadRow;
	}

	// Load row values from recordset
	function LoadRowValues(&$rs) {
		global $pv_deltron_cat;
		$pv_deltron_cat->id->setDbValue($rs->fields('id'));
		$pv_deltron_cat->categoria->setDbValue($rs->fields('categoria'));
		$pv_deltron_cat->margen->setDbValue($rs->fields('margen'));
	}

	// Render row values based on field settings
	function RenderRow() {
		global $conn, $Security, $pv_deltron_cat;

		// Call Row_Rendering event
		$pv_deltron_cat->Row_Rendering();

		// Common render codes for all row types
		// id

		$pv_deltron_cat->id->CellCssStyle = "";
		$pv_deltron_cat->id->CellCssClass = "";

		// categoria
		$pv_deltron_cat->categoria->CellCssStyle = "";
		$pv_deltron_cat->categoria->CellCssClass = "";

		// margen
		$pv_deltron_cat->margen->CellCssStyle = "";
		$pv_deltron_cat->margen->CellCssClass = "";
		if ($pv_deltron_cat->RowType == EW_ROWTYPE_VIEW) { // View row

			// id
			$pv_deltron_cat->id->ViewValue = $pv_deltron_cat->id->CurrentValue;
			$pv_deltron_cat->id->CssStyle = "";
			$pv_deltron_cat->id->CssClass = "";
			$pv_deltron_cat->id->ViewCustomAttributes = "";

			// categoria
			$pv_deltron_cat->categoria->ViewValue = $pv_deltron_cat->categoria->CurrentValue;
			$pv_deltron_cat->categoria->CssStyle = "";
			$pv_deltron_cat->categoria->CssClass = "";
			$pv_deltron_cat->categoria->ViewCustomAttributes = "";

			// margen
			$pv_deltron_cat->margen->ViewValue = $pv_deltron_cat->margen->CurrentValue;
			$pv_deltron_cat->margen->CssStyle = "";
			$pv_deltron_cat->margen->CssClass = "";
			$pv_deltron_cat->margen->ViewCustomAttributes = "";

			// id
			$pv_deltron_cat->id->HrefValue = "";

			// categoria
			$pv_deltron_cat->categoria->HrefValue = "";

			// margen
			$pv_deltron_cat->margen->HrefValue = "";
		}

		// Call Row Rendered event
		$pv_deltron_cat->Row_Rendered();
	}

	// Page Load event
	function Page_Load() {

		//echo "Page Load";
	}

	// Page Unload event
	function Page_Unload() {

		//echo "Page Unload";
	}
}
?>
